@@ -72,31 +72,22 @@ TREELITE_DLL int TreeliteAnnotationFree(AnnotationHandle handle);
  * \{
  */
 /*!
- * \brief create a compiler with a given name
+ * \brief Create a compiler with a given name
  * \param name name of compiler
+ * \param params_json_str JSON string representing the parameters for the compiler
  * \param out created compiler
  * \return 0 for success, -1 for failure
  */
-TREELITE_DLL int TreeliteCompilerCreate(const char* name,
-                                        CompilerHandle* out);
+TREELITE_DLL int TreeliteCompilerCreateV2(const char* name, const char* params_json_str,
+                                          CompilerHandle* out);
 /*!
- * \brief set a parameter for a compiler
- * \param handle compiler
- * \param name name of parameter
- * \param value value of parameter
- * \return 0 for success, -1 for failure
- */
-TREELITE_DLL int TreeliteCompilerSetParam(CompilerHandle handle,
-                                          const char* name,
-                                          const char* value);
-/*!
- * \brief generate prediction code from a tree ensemble model. The code will
+ * \brief Generate prediction code from a tree ensemble model. The code will
  *        be C99 compliant. One header file (.h) will be generated, along with
  *        one or more source files (.c).
  *
  * Usage example:
  * \code
- *   TreeliteCompilerGenerateCode(compiler, model, 1, "./my/model");
+ *   TreeliteCompilerGenerateCodeV2(compiler, model, "./my/model");
  *   // files to generate: ./my/model/header.h, ./my/model/main.c
  *   // if parallel compilation is enabled:
  *   // ./my/model/header.h, ./my/model/main.c, ./my/model/tu0.c,
@@ -104,14 +95,12 @@ TREELITE_DLL int TreeliteCompilerSetParam(CompilerHandle handle,
  * \endcode
  * \param compiler handle for compiler
  * \param model handle for tree ensemble model
- * \param verbose whether to produce extra messages
  * \param dirpath directory to store header and source files
  * \return 0 for success, -1 for failure
  */
-TREELITE_DLL int TreeliteCompilerGenerateCode(CompilerHandle compiler,
-                                              ModelHandle model,
-                                              int verbose,
-                                              const char* dirpath);
+TREELITE_DLL int TreeliteCompilerGenerateCodeV2(CompilerHandle compiler,
+                                                ModelHandle model,
+                                                const char* dirpath);
 /*!
  * \brief delete compiler from memory
  * \param handle compiler to remove
@@ -172,6 +161,16 @@ TREELITE_DLL int TreeliteLoadXGBoostModelFromMemoryBuffer(const void* buf,
                                                           size_t len,
                                                           ModelHandle* out);
 
+/*!
+ * \brief Load a LightGBM model from a string. The string should be created with the
+ *        model_to_string() method in LightGBM.
+ * \param model_str the model string
+ * \param out loaded model
+ * \return 0 for success, -1 for failure
+ */
+TREELITE_DLL int TreeliteLoadLightGBMModelFromString(const char* model_str,
+                                                     ModelHandle* out);
+
 /*!
  * \brief Load a scikit-learn random forest regressor model from a collection of arrays. Refer to
  *        https://scikit-learn.org/stable/auto_examples/tree/plot_unveil_tree_structure.html to
@@ -192,6 +191,8 @@ TREELITE_DLL int TreeliteLoadXGBoostModelFromMemoryBuffer(const void* buf,
  *              if node k is a leaf node.
  * \param n_node_samples n_node_samples[i][k] stores the number of data samples associated with
  *                       node k of the i-th tree.
+ * \param weighted_n_node_samples weighted_n_node_samples[i][k] stores the sum of weighted data
+ *                                samples associated with node k of the i-th tree.
  * \param impurity impurity[i][k] stores the impurity measure (gini, entropy etc) associated with
  *                 node k of the i-th tree.
  * \param out pointer to store the loaded model
@@ -200,8 +201,40 @@ TREELITE_DLL int TreeliteLoadXGBoostModelFromMemoryBuffer(const void* buf,
 TREELITE_DLL int TreeliteLoadSKLearnRandomForestRegressor(
     int n_estimators, int n_features, const int64_t* node_count, const int64_t** children_left,
     const int64_t** children_right, const int64_t** feature, const double** threshold,
-    const double** value, const int64_t** n_node_samples, const double** impurity,
-    ModelHandle* out);
+    const double** value, const int64_t** n_node_samples, const double** weighted_n_node_samples,
+    const double** impurity, ModelHandle* out);
+
+/*!
+ * \brief Load a scikit-learn isolation forest model from a collection of arrays. Refer to
+ *        https://scikit-learn.org/stable/auto_examples/tree/plot_unveil_tree_structure.html to
+ *        learn the mearning of the arrays in detail.
+ * \param n_estimators number of trees in the random forest
+ * \param n_features number of features in the training data
+ * \param node_count node_count[i] stores the number of nodes in the i-th tree
+ * \param children_left children_left[i][k] stores the ID of the left child node of node k of the
+ *                      i-th tree. This is only defined if node k is an internal (non-leaf) node.
+ * \param children_right children_right[i][k] stores the ID of the right child node of node k of the
+ *                       i-th tree. This is only defined if node k is an internal (non-leaf) node.
+ * \param feature feature[i][k] stores the ID of the feature used in the binary tree split at node k
+ *                of the i-th tree. This is only defined if node k is an internal (non-leaf) node.
+ * \param threshold threshold[i][k] stores the threshold used in the binary tree split at node k of
+ *                  the i-th tree. This is only defined if node k is an internal (non-leaf) node.
+ * \param value value[i][k] stores the expected isolation depth of node k of the i-th tree. This is
+ *              only defined if node k is a leaf node.
+ * \param n_node_samples n_node_samples[i][k] stores the number of data samples associated with
+ *                       node k of the i-th tree.
+ * \param weighted_n_node_samples weighted_n_node_samples[i][k] stores the sum of weighted data
+ *                                samples associated with node k of the i-th tree.
+ * \param impurity not used, but must be passed as array of arrays for each tree and node.
+ * \param ratio_c standardizing constant to use for calculation of the anomaly score.
+ * \param out pointer to store the loaded model
+ * \return 0 for success, -1 for failure
+ */
+TREELITE_DLL int TreeliteLoadSKLearnIsolationForest(
+    int n_estimators, int n_features, const int64_t* node_count, const int64_t** children_left,
+    const int64_t** children_right, const int64_t** feature, const double** threshold,
+    const double** value, const int64_t** n_node_samples, const double** weighted_n_node_samples,
+    const double** impurity, const double ratio_c, ModelHandle* out);
 
 /*!
  * \brief Load a scikit-learn random forest classifier model from a collection of arrays. Refer to
@@ -224,6 +257,8 @@ TREELITE_DLL int TreeliteLoadSKLearnRandomForestRegressor(
  *              if node k is a leaf node.
  * \param n_node_samples n_node_samples[i][k] stores the number of data samples associated with
  *                       node k of the i-th tree.
+ * \param weighted_n_node_samples weighted_n_node_samples[i][k] stores the sum of weighted data
+ *                                samples associated with node k of the i-th tree.
  * \param impurity impurity[i][k] stores the impurity measure (gini, entropy etc) associated with
  *                 node k of the i-th tree.
  * \param out pointer to store the loaded model
@@ -233,7 +268,7 @@ TREELITE_DLL int TreeliteLoadSKLearnRandomForestClassifier(
     int n_estimators, int n_features, int n_classes, const int64_t* node_count,
     const int64_t** children_left, const int64_t** children_right, const int64_t** feature,
     const double** threshold, const double** value, const int64_t** n_node_samples,
-    const double** impurity, ModelHandle* out);
+    const double** weighted_n_node_samples, const double** impurity, ModelHandle* out);
 
 /*!
  * \brief Load a scikit-learn gradient boosting regressor model from a collection of arrays. Refer
@@ -254,6 +289,8 @@ TREELITE_DLL int TreeliteLoadSKLearnRandomForestClassifier(
  *              if node k is a leaf node.
  * \param n_node_samples n_node_samples[i][k] stores the number of data samples associated with
  *                       node k of the i-th tree.
+ * \param weighted_n_node_samples weighted_n_node_samples[i][k] stores the sum of weighted data
+ *                                samples associated with node k of the i-th tree.
  * \param impurity impurity[i][k] stores the impurity measure (gini, entropy etc) associated with
  *                 node k of the i-th tree.
  * \param out pointer to store the loaded model
@@ -262,8 +299,8 @@ TREELITE_DLL int TreeliteLoadSKLearnRandomForestClassifier(
 TREELITE_DLL int TreeliteLoadSKLearnGradientBoostingRegressor(
     int n_estimators, int n_features, const int64_t* node_count, const int64_t** children_left,
     const int64_t** children_right, const int64_t** feature, const double** threshold,
-    const double** value, const int64_t** n_node_samples, const double** impurity,
-    ModelHandle* out);
+    const double** value, const int64_t** n_node_samples, const double** weighted_n_node_samples,
+    const double** impurity, ModelHandle* out);
 
 /*!
  * \brief Load a scikit-learn gradient boosting classifier model from a collection of arrays. Refer
@@ -285,6 +322,8 @@ TREELITE_DLL int TreeliteLoadSKLearnGradientBoostingRegressor(
  *              if node k is a leaf node.
  * \param n_node_samples n_node_samples[i][k] stores the number of data samples associated with
  *                       node k of the i-th tree.
+ * \param weighted_n_node_samples weighted_n_node_samples[i][k] stores the sum of weighted data
+ *                                samples associated with node k of the i-th tree.
  * \param impurity impurity[i][k] stores the impurity measure (gini, entropy etc) associated with
  *                 node k of the i-th tree.
  * \param out pointer to store the loaded model
@@ -294,7 +333,7 @@ TREELITE_DLL int TreeliteLoadSKLearnGradientBoostingClassifier(
     int n_estimators, int n_features, int n_classes, const int64_t* node_count,
     const int64_t** children_left, const int64_t** children_right, const int64_t** feature,
     const double** threshold, const double** value, const int64_t** n_node_samples,
-    const double** impurity, ModelHandle* out);
+    const double** weighted_n_node_samples, const double** impurity, ModelHandle* out);
 
 /*!
  * \brief Query the number of trees in the model
@@ -345,6 +384,26 @@ TREELITE_DLL int TreeliteSerializeModel(const char* filename, ModelHandle handle
  */
 TREELITE_DLL int TreeliteDeserializeModel(const char* filename, ModelHandle* out);
 
+/*!
+ * \brief Concatenate multiple model objects into a single model object by copying
+ *        all member trees into the destination model object
+ * \param objs Pointer to the beginning of the list of model objects
+ * \param len Number of model objects
+ * \param out Used to save the concatenated model
+ */
+TREELITE_DLL int TreeliteConcatenateModelObjects(const ModelHandle* objs, size_t len,
+                                                 ModelHandle* out);
+
+/*!
+ * \brief Dump a model object as a JSON string
+ * \param handle The handle to the model object
+ * \param pretty_print Whether to pretty-print JSON string (0 for false, != 0 for true)
+ * \param out_json_str The JSON string
+ * \return 0 for success, -1 for failure
+ */
+TREELITE_DLL int TreeliteDumpAsJSON(ModelHandle handle, int pretty_print,
+                                    const char** out_json_str);
+
 /*!
  * \brief delete model from memory
  * \param handle model to remove
@@ -361,10 +420,33 @@ TREELITE_DLL int TreeliteFreeModel(ModelHandle handle);
  * \{
  */
 
-TREELITE_DLL int TreeliteGTILGetPredictOutputSize(ModelHandle handle, size_t num_row, size_t* out);
+/*!
+ * \brief Given a batch of data rows, query the necessary size of array to hold predictions for all
+ *        data points.
+ * \param model Treelite Model object
+ * \param num_row Number of rows in the input
+ * \param out Size of output buffer that should be allocated
+ * \return 0 for success; -1 for failure
+ */
+TREELITE_DLL int TreeliteGTILGetPredictOutputSize(ModelHandle model, size_t num_row, size_t* out);
 
-TREELITE_DLL int TreeliteGTILPredict(ModelHandle handle, const float* input, size_t num_row,
-                                     float* output, int pred_transform, size_t* out_result_size);
+/*!
+ * \brief Predict with a 2D dense array
+ * \param model Treelite Model object
+ * \param input The 2D data array, laid out in row-major layout
+ * \param num_row Number of rows in the data matrix.
+ * \param output Pointer to buffer to store the output. Call TreeliteGTILGetPredictOutputSize()
+ *               to get the amount of buffer you should allocate for this parameter.
+ * \param nthread number of CPU threads to use. Set <= 0 to use all CPU cores.
+ * \param pred_transform After computing the prediction score, whether to transform it.
+ * \param out_result_size Size of output. This could be smaller than
+ *                        TreeliteGTILGetPredictOutputSize() but could never be larger than
+ *                        TreeliteGTILGetPredictOutputSize().
+ * \return 0 for success; -1 for failure
+ */
+TREELITE_DLL int TreeliteGTILPredict(ModelHandle model, const float* input, size_t num_row,
+                                     float* output, int nthread, int pred_transform,
+                                     size_t* out_result_size);
 
 /*! \} */
 
