@@ -240,6 +240,17 @@ int TreeliteDeserializeModel(const char* filename, ModelHandle* out) {
   API_END();
 }
 
+int TreeliteConcatenateModelObjects(const ModelHandle* objs, size_t len,
+                                    ModelHandle* out) {
+  API_BEGIN();
+  std::vector<const Model*> model_objs(len, nullptr);
+  std::transform(objs, objs + len, model_objs.begin(),
+                 [](const ModelHandle e) { return static_cast<const Model*>(e); });
+  auto concatenated_model = ConcatenateModelObjects(model_objs);
+  *out = static_cast<ModelHandle>(concatenated_model.release());
+  API_END();
+}
+
 int TreeliteDumpAsJSON(ModelHandle handle, int pretty_print, const char** out_json_str) {
   API_BEGIN();
   auto* model_ = static_cast<Model*>(handle);
@@ -255,19 +266,19 @@ int TreeliteFreeModel(ModelHandle handle) {
   API_END();
 }
 
-int TreeliteGTILGetPredictOutputSize(ModelHandle handle, size_t num_row, size_t* out) {
+int TreeliteGTILGetPredictOutputSize(ModelHandle model, size_t num_row, size_t* out) {
   API_BEGIN();
-  const auto* model_ = static_cast<const Model*>(handle);
+  const auto* model_ = static_cast<const Model*>(model);
   *out = gtil::GetPredictOutputSize(model_, num_row);
   API_END();
 }
 
-int TreeliteGTILPredict(ModelHandle handle, const float* input, size_t num_row, float* output,
-                        int pred_transform, size_t* out_result_size) {
+int TreeliteGTILPredict(ModelHandle model, const float* input, size_t num_row, float* output,
+                        int nthread, int pred_transform, size_t* out_result_size) {
   API_BEGIN();
-  const auto* model_ = static_cast<const Model*>(handle);
+  const auto* model_ = static_cast<const Model*>(model);
   *out_result_size =
-      gtil::Predict(model_, input, num_row, output, (pred_transform == 1));
+      gtil::Predict(model_, input, num_row, output, nthread, (pred_transform == 1));
   API_END();
 }
 
