@@ -10,6 +10,7 @@
 #define TREELITE_COMPILER_NATIVE_TYPEINFO_CTYPES_H_
 
 #include <treelite/base.h>
+#include <treelite/error.h>
 #include <string>
 
 namespace treelite {
@@ -24,7 +25,7 @@ namespace native {
 inline std::string TypeInfoToCTypeString(TypeInfo type) {
   switch (type) {
   case TypeInfo::kInvalid:
-    throw std::runtime_error("Invalid type");
+    throw Error("Invalid type");
     return "";
   case TypeInfo::kUInt32:
     return "uint32_t";
@@ -33,8 +34,7 @@ inline std::string TypeInfoToCTypeString(TypeInfo type) {
   case TypeInfo::kFloat64:
     return "double";
   default:
-    throw std::runtime_error(std::string("Unrecognized type: ")
-                             + std::to_string(static_cast<int>(type)));
+    throw Error(std::string("Unrecognized type: ") + std::to_string(static_cast<int>(type)));
     return "";
   }
 }
@@ -48,15 +48,14 @@ inline std::string CExpForTypeInfo(TypeInfo type) {
   switch (type) {
   case TypeInfo::kInvalid:
   case TypeInfo::kUInt32:
-    throw std::runtime_error(std::string("Invalid type: ") + TypeInfoToString(type));
+    throw Error(std::string("Invalid type: ") + TypeInfoToString(type));
     return "";
   case TypeInfo::kFloat32:
     return "expf";
   case TypeInfo::kFloat64:
     return "exp";
   default:
-    throw std::runtime_error(std::string("Unrecognized type: ")
-                             + std::to_string(static_cast<int>(type)));
+    throw Error(std::string("Unrecognized type: ") + std::to_string(static_cast<int>(type)));
     return "";
   }
 }
@@ -70,15 +69,14 @@ inline std::string CExp2ForTypeInfo(TypeInfo type) {
   switch (type) {
   case TypeInfo::kInvalid:
   case TypeInfo::kUInt32:
-    throw std::runtime_error(std::string("Invalid type: ") + TypeInfoToString(type));
+    throw Error(std::string("Invalid type: ") + TypeInfoToString(type));
     return "";
   case TypeInfo::kFloat32:
     return "exp2f";
   case TypeInfo::kFloat64:
     return "exp2";
   default:
-    throw std::runtime_error(std::string("Unrecognized type: ")
-                             + std::to_string(static_cast<int>(type)));
+    throw Error(std::string("Unrecognized type: ") + std::to_string(static_cast<int>(type)));
     return "";
   }
 }
@@ -92,15 +90,14 @@ inline std::string CCopySignForTypeInfo(TypeInfo type) {
   switch (type) {
   case TypeInfo::kInvalid:
   case TypeInfo::kUInt32:
-    throw std::runtime_error(std::string("Invalid type: ") + TypeInfoToString(type));
+    throw Error(std::string("Invalid type: ") + TypeInfoToString(type));
     return "";
   case TypeInfo::kFloat32:
     return "copysignf";
   case TypeInfo::kFloat64:
     return "copysign";
   default:
-    throw std::runtime_error(std::string("Unrecognized type: ")
-                             + std::to_string(static_cast<int>(type)));
+    throw Error(std::string("Unrecognized type: ") + std::to_string(static_cast<int>(type)));
     return "";
   }
 }
@@ -114,15 +111,14 @@ inline std::string CLog1PForTypeInfo(TypeInfo type) {
   switch (type) {
   case TypeInfo::kInvalid:
   case TypeInfo::kUInt32:
-    throw std::runtime_error(std::string("Invalid type: ") + TypeInfoToString(type));
+    throw Error(std::string("Invalid type: ") + TypeInfoToString(type));
     return "";
   case TypeInfo::kFloat32:
     return "log1pf";
   case TypeInfo::kFloat64:
     return "log1p";
   default:
-    throw std::runtime_error(std::string("Unrecognized type: ")
-                             + std::to_string(static_cast<int>(type)));
+    throw Error(std::string("Unrecognized type: ") + std::to_string(static_cast<int>(type)));
     return "";
   }
 }
